@@ -19,6 +19,17 @@ class AuthManager:
         if Configuration.api_key is not None:
             http_request.headers['apikey'] = Configuration.api_key
             return
+
+        # If this is SessionId based authentication, we add the session-id header
+        if Configuration.session_id is not None:
+            http_request.headers['session-id'] = Configuration.session_id
+            return
+
+        # If this is Open-Id based authentication, we add the open-id-token header
+        if Configuration.open_id_token is not None:
+            http_request.headers['open-id-token'] = Configuration.open_id_token
+            return
+
         cls.check_auth(Configuration)
         token = Configuration.auth_token.access_token
         token_type = Configuration.auth_token.token_type
@@ -43,7 +54,11 @@ class AuthManager:
         if Configuration.domain is not None:
             body.domain = Configuration.domain
 
+        if Configuration.otp_type:
+            body.otp_type = Configuration.otp_type
+            body.otp_code = Configuration.otp_code
+
         auth_controller = AccessTokensController(Configuration)
         token = auth_controller.create_generate_access_token(body)
         Configuration.auth_token = token
-        return token
\ No newline at end of file
+        return token
