@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class AlertCategoryListGetAlertsEnum(object):
 
@@ -8,7 +8,6 @@ class AlertCategoryListGetAlertsEnum(object):
     TODO: type enum description here.
 
     Attributes:
-
         KDISK: TODO: type description here.
         KNODE: TODO: type description here.
         KCLUSTER: TODO: type description here.
@@ -40,8 +39,10 @@ class AlertCategoryListGetAlertsEnum(object):
         KARCHIVALRESTORE: TODO: type description here.
         KREMOTEREPLICATION: TODO: type description here.
         KQUOTA: TODO: type description here.
+        KCDP: TODO: type description here.
 
     """
+
     KDISK = 'kDisk'
 
     KNODE = 'kNode'
@@ -104,3 +105,5 @@ class AlertCategoryListGetAlertsEnum(object):
 
     KQUOTA = 'kQuota'
 
+    KCDP = 'kCDP'
+
