@@ -1,14 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class BondingModeEnum(object):
 
     """Implementation of the 'BondingMode' enum.
+    Specifies the new bonding mode. 'kActiveBackup' indicates active backup
+    bonding mode. 'k802_3ad' indicates 802.3ad bonding mode.
 
-    Specifies the bonding mode to use for this bond. If not specified,
-    this value will default to 'kActiveBackup'.
-    'kActiveBackup' indicates active backup bonding mode.
-    'k802_3ad' indicates 802.3ad bonding mode.
 
     Attributes:
         KACTIVEBACKUP: TODO: type description here.
@@ -19,4 +17,3 @@ class BondingModeEnum(object):
     KACTIVEBACKUP = 'kActiveBackup'
 
     K802_3AD = 'k802_3ad'
-
