@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright 2023 Cohesity Inc.
 
-
 class C2SAccessPortal(object):
 
     """Implementation of the 'C2SAccessPortal' model.
@@ -9,31 +8,34 @@ class C2SAccessPortal(object):
     Specifies information required to connect to CAP to get AWS credentials.
     C2SAccessPortal(CAP) is AWS commercial cloud service access portal.
 
+
     Attributes:
+
         agency (string): Name of the agency.
         base_url (string): The base url of C2S CAP server.
         client_certificate_password (string): Encrypted password of the client
             private key.
         mission (string): Name of the mission.
         role (string): Role type.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "agency":'agency',
         "base_url":'baseUrl',
         "client_certificate_password":'clientCertificatePassword',
         "mission":'mission',
-        "role":'role'
+        "role":'role',
     }
-
     def __init__(self,
                  agency=None,
                  base_url=None,
                  client_certificate_password=None,
                  mission=None,
-                 role=None):
+                 role=None,
+            ):
+
         """Constructor for the C2SAccessPortal class"""
 
         # Initialize members of the class
@@ -43,7 +45,6 @@ class C2SAccessPortal(object):
         self.mission = mission
         self.role = role
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -69,10 +70,10 @@ class C2SAccessPortal(object):
         role = dictionary.get('role')
 
         # Return an object of this model
-        return cls(agency,
-                   base_url,
-                   client_certificate_password,
-                   mission,
-                   role)
-
-
+        return cls(
+            agency,
+            base_url,
+            client_certificate_password,
+            mission,
+            role
+)
\ No newline at end of file
