@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class CouchbaseCluster(object):
 
@@ -8,23 +7,26 @@ class CouchbaseCluster(object):
 
     Specifies an Object containing information about a couchbase cluster.
 
+
     Attributes:
-    seeds (list of string): Seeds of this Couchbase Cluster.
+
+        seeds (list of string): Seeds of this Couchbase Cluster.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "seeds":'seeds'
+        "seeds":'seeds',
     }
-
     def __init__(self,
-                 seeds=None):
+                 seeds=None,
+            ):
+
         """Constructor for the CouchbaseCluster class"""
 
         # Initialize members of the class
         self.seeds = seeds
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -43,9 +45,9 @@ class CouchbaseCluster(object):
             return None
 
         # Extract variables from the dictionary
-        seeds = dictionary.get('seeds')
+        seeds = dictionary.get("seeds")
 
         # Return an object of this model
-        return cls(seeds)
-
-
+        return cls(
+            seeds
+)
\ No newline at end of file
