@@ -1,16 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class DesiredWalLocationEnum(object):
 
     """Implementation of the 'DesiredWalLocation' enum.
+    Desired location for write ahead logs(wal). 'kHomePartition' indicates
+    desired wal location to be the home partition. 'kDisk' indicates desired
+    wal location to be the same disk as chunk repo. 'kScribe' indicates desired
+    wal location to be scribe. 'kScribeTable' indicates chunk repository state
+    is kept as key-value pairs in scribe.
 
-    Desired location for write ahead logs(wal).
-    'kHomePartition' indicates desired wal location to be the home partition.
-    'kDisk' indicates desired wal location to be the same disk as chunk repo.
-    'kScribe' indicates desired wal location to be scribe.
-    'kScribeTable' indicates chunk repository state is kept as key-value
-    pairs in scribe.
 
     Attributes:
         KHOMEPARTITION: TODO: type description here.
@@ -27,4 +26,3 @@ class DesiredWalLocationEnum(object):
     KSCRIBE = 'kScribe'
 
     KSCRIBETABLE = 'kScribeTable'
-
