@@ -1,39 +1,41 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class FileStatInfo(object):
 
     """Implementation of the 'FileStatInfo' model.
 
-    TODO: type model description here.
+    TODO: type description here.
+
 
     Attributes:
-        backup_source_inode_id (long|int): Source inode id metadata for
-            certain adapters e.g. Netapp.
+
+        backup_source_inode_id (long|int): Source inode id metadata for certain
+            adapters e.g. Netapp.
         mtime_usecs (long|int): If this is a file, the mtime as returned by
             stat.
-        size (long|int): If this is a file, the size of the file as returned
-            by stat.
+        size (long|int): If this is a file, the size of the file as returned by
+            stat.
         mtype (int): The type of this entity. This field will not be populated
             for ReadDir results, since the DirEntry already contains the type
             information.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "backup_source_inode_id":'backupSourceInodeId',
         "mtime_usecs":'mtimeUsecs',
         "size":'size',
-        "mtype":'type'
+        "mtype":'type',
     }
-
     def __init__(self,
                  backup_source_inode_id=None,
                  mtime_usecs=None,
                  size=None,
-                 mtype=None):
+                 mtype=None,
+            ):
+
         """Constructor for the FileStatInfo class"""
 
         # Initialize members of the class
@@ -42,7 +44,6 @@ class FileStatInfo(object):
         self.size = size
         self.mtype = mtype
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -67,9 +68,9 @@ class FileStatInfo(object):
         mtype = dictionary.get('type')
 
         # Return an object of this model
-        return cls(backup_source_inode_id,
-                   mtime_usecs,
-                   size,
-                   mtype)
-
-
+        return cls(
+            backup_source_inode_id,
+            mtime_usecs,
+            size,
+            mtype
+)
\ No newline at end of file
