@@ -1,26 +1,23 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class GcpTypeEnum(object):
 
     """Implementation of the 'GcpType' enum.
-
     Specifies the entity type such as 'kIAMUser' if the environment is kGCP.
-    Specifies the type of a GCP source entity.
-    'kIAMUser' indicates a unique user within a GCP account.
-    'kProject' represents compute resources and storage.
-    'kRegion' indicates a geographical region in the global infrastructure.
-    'kAvailabilityZone' indicates an availability zone within a region.
-    'kVirtualMachine' indicates a Virtual Machine running in GCP environment.
-    'kVPC' indicates a virtual private cloud (VPC) network within GCP.
-    'kSubnet' indicates a subnet inside the VPC.
-    'kNetworkSecurityGroup' represents a network security group.
-    'kInstanceType' represents various machine types.
-    'kLabel' represents a label present on the instances.
-    'kMetaData' represents a custom metadata present on instances.
-    'kTag' represents a network tag on instances.
-    'kVPCConnector' represents a VPC connector used for serverless VPC
-    access.
+    Specifies the type of a GCP source entity. 'kIAMUser' indicates a unique
+    user within a GCP account. 'kProject' represents compute resources and
+    storage. 'kRegion' indicates a geographical region in the global
+    infrastructure. 'kAvailabilityZone' indicates an availability zone within a
+    region. 'kVirtualMachine' indicates a Virtual Machine running in GCP
+    environment. 'kVPC' indicates a virtual private cloud (VPC) network within
+    GCP. 'kSubnet' indicates a subnet inside the VPC. 'kNetworkSecurityGroup'
+    represents a network security group. 'kInstanceType' represents various
+    machine types. 'kLabel' represents a label present on the instances.
+    'kMetaData' represents a custom metadata present on instances. 'kTag'
+    represents a network tag on instances. 'kVPCConnector' represents a VPC
+    connector used for serverless VPC access.
+
 
     Attributes:
         KIAMUSER: TODO: type description here.
@@ -64,4 +61,3 @@ class GcpTypeEnum(object):
     KTAG = 'kTag'
 
     KVPCCONNECTOR = 'kVPCConnector'
-
