@@ -1,27 +1,26 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class IdpPrincipalsAddParameters(object):
 
     """Implementation of the 'IdpPrincipalsAddParameters' model.
 
-    Specifies the settings for adding new users and groups
-    for Idp principals.
-    These users and groups are added to the Cohesity Cluster.
-    You cannot create users and groups in the default Cohesity domain
-    called 'LOCAL' using this operation.
+    Specifies the settings for adding new users and groups for Idp principals.
+    These users and groups are added to the Cohesity Cluster. You cannot create
+    users and groups in the default Cohesity domain called 'LOCAL' using this
+    operation.
+
 
     Attributes:
+
         domain (string): Specifies the name of the Idp where the referenced
             principal is stored.
-        object_class (ObjectClassIdpPrincipalsAddParametersEnum): Specifies
-            the type of the referenced Idp principal. If 'kGroup', the
-            referenced Idp principal is a group. If 'kUser', the referenced
-            Idp principal is a user. 'kUser' specifies a user object class.
-            'kGroup' specifies a group object class. 'kComputer' specifies a
-            computer object class. 'kWellKnownPrincipal' specifies a well
-            known principal.
+        object_class (ObjectClassEnum): Specifies the type of the referenced
+            Idp principal. If 'kGroup', the referenced Idp principal is a
+            group. If 'kUser', the referenced Idp principal is a user. 'kUser'
+            specifies a user object class. 'kGroup' specifies a group object
+            class. 'kComputer' specifies a computer object class.
+            'kWellKnownPrincipal' specifies a well known principal.
             'kServiceAccount' specifies a service account object class.
         principal_name (string): Specifies the name of the Idp principal, that
             will be referenced by the group or user. The name of the Idp
@@ -38,24 +37,25 @@ class IdpPrincipalsAddParameters(object):
             associated with the Cohesity 'View' role, 'joe' can log in to the
             Cohesity Dashboard and has a read-only view of the data on the
             Cohesity Cluster.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "domain":'domain',
         "object_class":'objectClass',
         "principal_name":'principalName',
         "restricted":'restricted',
-        "roles":'roles'
+        "roles":'roles',
     }
-
     def __init__(self,
                  domain=None,
                  object_class=None,
                  principal_name=None,
                  restricted=None,
-                 roles=None):
+                 roles=None,
+            ):
+
         """Constructor for the IdpPrincipalsAddParameters class"""
 
         # Initialize members of the class
@@ -65,7 +65,6 @@ class IdpPrincipalsAddParameters(object):
         self.restricted = restricted
         self.roles = roles
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -88,13 +87,13 @@ class IdpPrincipalsAddParameters(object):
         object_class = dictionary.get('objectClass')
         principal_name = dictionary.get('principalName')
         restricted = dictionary.get('restricted')
-        roles = dictionary.get('roles')
+        roles = dictionary.get("roles")
 
         # Return an object of this model
-        return cls(domain,
-                   object_class,
-                   principal_name,
-                   restricted,
-                   roles)
-
-
+        return cls(
+            domain,
+            object_class,
+            principal_name,
+            restricted,
+            roles
+)
\ No newline at end of file
