@@ -1,15 +1,18 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.network_pool
 
+
 class IsilonAccessZone(object):
 
     """Implementation of the 'IsilonAccessZone' model.
 
     Specifies information about access zone in an Isilon Cluster.
 
+
     Attributes:
+
         groupnet (string): Specifies the groupnet name of the Isilon Access
             Zone.
         id (long|int): Specifies the id of the access zone.
@@ -18,24 +21,25 @@ class IsilonAccessZone(object):
             associated with the Isilon Access Zone.
         path (string): Specifies the path of the access zone in ifs. This
             should include the leading "/ifs/".
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "groupnet":'groupnet',
         "id":'id',
         "name":'name',
         "network_pools":'networkPools',
-        "path":'path'
+        "path":'path',
     }
-
     def __init__(self,
                  groupnet=None,
                  id=None,
                  name=None,
                  network_pools=None,
-                 path=None):
+                 path=None,
+            ):
+
         """Constructor for the IsilonAccessZone class"""
 
         # Initialize members of the class
@@ -45,7 +49,6 @@ class IsilonAccessZone(object):
         self.network_pools = network_pools
         self.path = path
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -75,10 +78,10 @@ class IsilonAccessZone(object):
         path = dictionary.get('path')
 
         # Return an object of this model
-        return cls(groupnet,
-                   id,
-                   name,
-                   network_pools,
-                   path)
-
-
+        return cls(
+            groupnet,
+            id,
+            name,
+            network_pools,
+            path
+)
\ No newline at end of file
