@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class LdapProviderStatus(object):
 
@@ -8,25 +7,27 @@ class LdapProviderStatus(object):
 
     LDAP provider status struct.
 
+
     Attributes:
+
         status_message (string): Specifies the connection status message of an
             LDAP provider.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "status_message":'statusMessage'
+        "status_message":'statusMessage',
     }
-
     def __init__(self,
-                 status_message=None):
+                 status_message=None,
+            ):
+
         """Constructor for the LdapProviderStatus class"""
 
         # Initialize members of the class
         self.status_message = status_message
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -48,6 +49,6 @@ class LdapProviderStatus(object):
         status_message = dictionary.get('statusMessage')
 
         # Return an object of this model
-        return cls(status_message)
-
-
+        return cls(
+            status_message
+)
\ No newline at end of file
