@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class MigrateOracleCloneParams(object):
 
@@ -9,39 +8,37 @@ class MigrateOracleCloneParams(object):
     OracleUpdateRestoreTaskOptions encapsulates information needed for
     executing migration of a successful Oracle Clone task.
 
+
     Attributes:
+
         delay_secs (long|int): The delay in secs, after which the migration of
-            the Clone should be triggered.
-            "0" - Means the Migration should start as soon as the Clone
-            successfully finished. That is the default behaviour.
-
-            0 < - Means the migration will start when user triggers migration
-            from UI.
-
-            > 0 - Means the delay in seconds after which the migration of the
-            clone would be triggered. [ For now this is not supported ]
-
+            the Clone should be triggered. "0" - Means the Migration should
+            start as soon as the Clone successfully finished. That is the
+            default behaviour.  0 < - Means the migration will start when user
+            triggers migration from UI.  > 0 - Means the delay in seconds after
+            which the migration of the clone would be triggered. [ For now this
+            is not supported ]
         target_path_vec (list of string): Vector of paths where the contents
             (i.e. datafile/redo-logs) of the clone DB will be migrated.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "delay_secs": 'delaySecs',
-        "target_path_vec": 'targetPathVec'
+        "delay_secs":'delaySecs',
+        "target_path_vec":'targetPathVec',
     }
-
     def __init__(self,
                  delay_secs=None,
-                 target_path_vec=None):
+                 target_path_vec=None,
+            ):
+
         """Constructor for the MigrateOracleCloneParams class"""
 
         # Initialize members of the class
         self.delay_secs = delay_secs
         self.target_path_vec = target_path_vec
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -60,11 +57,11 @@ class MigrateOracleCloneParams(object):
             return None
 
         # Extract variables from the dictionary
-        delay_secs = dictionary.get('delaySecs', None)
-        target_path_vec = dictionary.get('targetPathVec', None)
+        delay_secs = dictionary.get('delaySecs')
+        target_path_vec = dictionary.get("targetPathVec")
 
         # Return an object of this model
-        return cls(delay_secs,
-                   target_path_vec)
-
-
+        return cls(
+            delay_secs,
+            target_path_vec
+)
\ No newline at end of file
