@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class MongoDBConnectParams(object):
 
@@ -9,14 +8,12 @@ class MongoDBConnectParams(object):
     Specifies an Object containing information about a registered mongodb
     source.
 
+
     Attributes:
-        auth_type (AuthTypeMongoDBConnectParamsEnum): Specifies whether
-            authentication is configured on this MongoDB cluster.
-            Specifies the type of an MongoDB source entity.
-            'SCRAM'
-            'LDAP'
-            'NONE'
-            'KERBEROS'
+
+        auth_type (AuthTypeEnum): Specifies whether authentication is
+            configured on this MongoDB cluster. Specifies the type of an
+            MongoDB source entity. 'SCRAM' 'LDAP' 'NONE' 'KERBEROS'
         authenticating_database_name (string): Specifies the Authenticating
             Database for this MongoDB cluster.
         requires_ssl (bool): Specifies whether connection is allowed through
@@ -27,9 +24,9 @@ class MongoDBConnectParams(object):
         seeds (list of string): Specifies the seeds of this MongoDB Cluster.
         use_secondary_for_backup (bool): Set this to true if you want the
             system to peform backups from secondary nodes.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "auth_type":'authType',
@@ -37,16 +34,17 @@ class MongoDBConnectParams(object):
         "requires_ssl":'requiresSsl',
         "secondary_node_tag":'secondaryNodeTag',
         "seeds":'seeds',
-        "use_secondary_for_backup":'useSecondaryForBackup'
+        "use_secondary_for_backup":'useSecondaryForBackup',
     }
-
     def __init__(self,
                  auth_type=None,
                  authenticating_database_name=None,
                  requires_ssl=None,
                  secondary_node_tag=None,
                  seeds=None,
-                 use_secondary_for_backup=None):
+                 use_secondary_for_backup=None,
+            ):
+
         """Constructor for the MongoDBConnectParams class"""
 
         # Initialize members of the class
@@ -57,7 +55,6 @@ class MongoDBConnectParams(object):
         self.seeds = seeds
         self.use_secondary_for_backup = use_secondary_for_backup
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -80,15 +77,15 @@ class MongoDBConnectParams(object):
         authenticating_database_name = dictionary.get('authenticatingDatabaseName')
         requires_ssl = dictionary.get('requiresSsl')
         secondary_node_tag = dictionary.get('secondaryNodeTag')
-        seeds = dictionary.get('seeds')
+        seeds = dictionary.get("seeds")
         use_secondary_for_backup = dictionary.get('useSecondaryForBackup')
 
         # Return an object of this model
-        return cls(auth_type,
-                   authenticating_database_name,
-                   requires_ssl,
-                   secondary_node_tag,
-                   seeds,
-                   use_secondary_for_backup)
-
-
+        return cls(
+            auth_type,
+            authenticating_database_name,
+            requires_ssl,
+            secondary_node_tag,
+            seeds,
+            use_secondary_for_backup
+)
\ No newline at end of file
