@@ -25,7 +25,7 @@ class NetworkInterface(object):
         bonding_mode (int): Specifies the bonding mode if this interface is a
             bond.
         gateway (string): Specifies the gateway of the interface.
-        gateway6 (string): Specifies the gateway6 of the interface.
+        gateway_6 (string): Specifies the gateway6 of the interface.
         group (string): Specifies the group that this interface belongs to.
         id (long|int): Specifies the ID of this network interface.
         is_connected (bool): Specifies whether or not the Interface is
@@ -41,10 +41,10 @@ class NetworkInterface(object):
             interface is used for.
         speed (string): Specifies the speed of the Interface.
         static_ip (string): Specifies the static IP of the interface.
-        static_ip6 (string): Specifies the static IPv6 of the interface.
+        static_ip_6 (string): Specifies the static IPv6 of the interface.
         stats (InterfaceStats): Interface Stats.
         subnet (string): Specifies the subnet mask of the interface.
-        subnet6 (string): Specifies the subnet6 mask of the interface.
+        subnet_6 (string): Specifies the subnet6 mask of the interface.
         mtype (int): Specifies the type of interface.
         virtual_ip (string): Specifies the virtual IP of the interface.
     """
@@ -58,7 +58,7 @@ class NetworkInterface(object):
         "bond_slaves_details":'bondSlavesDetails',
         "bonding_mode":'bondingMode',
         "gateway":'gateway',
-        "gateway6":'gateway6',
+        "gateway_6":'gateway6',
         "group":'group',
         "id":'id',
         "is_connected":'isConnected',
@@ -71,10 +71,10 @@ class NetworkInterface(object):
         "services":'services',
         "speed":'speed',
         "static_ip":'staticIp',
-        "static_ip6":'staticIp6',
+        "static_ip_6":'staticIp6',
         "stats":'stats',
         "subnet":'subnet',
-        "subnet6":'subnet6',
+        "subnet_6":'subnet6',
         "mtype":'type',
         "virtual_ip":'virtualIp',
     }
@@ -85,7 +85,7 @@ class NetworkInterface(object):
                  bond_slaves_details=None,
                  bonding_mode=None,
                  gateway=None,
-                 gateway6=None,
+                 gateway_6=None,
                  group=None,
                  id=None,
                  is_connected=None,
@@ -98,10 +98,10 @@ class NetworkInterface(object):
                  services=None,
                  speed=None,
                  static_ip=None,
-                 static_ip6=None,
+                 static_ip_6=None,
                  stats=None,
                  subnet=None,
-                 subnet6=None,
+                 subnet_6=None,
                  mtype=None,
                  virtual_ip=None,
             ):
@@ -115,7 +115,7 @@ class NetworkInterface(object):
         self.bond_slaves_details = bond_slaves_details
         self.bonding_mode = bonding_mode
         self.gateway = gateway
-        self.gateway6 = gateway6
+        self.gateway_6 = gateway_6
         self.group = group
         self.id = id
         self.is_connected = is_connected
@@ -128,10 +128,10 @@ class NetworkInterface(object):
         self.services = services
         self.speed = speed
         self.static_ip = static_ip
-        self.static_ip6 = static_ip6
+        self.static_ip_6 = static_ip_6
         self.stats = stats
         self.subnet = subnet
-        self.subnet6 = subnet6
+        self.subnet_6 = subnet_6
         self.mtype = mtype
         self.virtual_ip = virtual_ip
 
@@ -163,7 +163,7 @@ class NetworkInterface(object):
                 bond_slaves_details.append(cohesity_management_sdk.models.bond_slave_info.BondSlaveInfo.from_dictionary(structure))
         bonding_mode = dictionary.get('bondingMode')
         gateway = dictionary.get('gateway')
-        gateway6 = dictionary.get('gateway6')
+        gateway_6 = dictionary.get('gateway6')
         group = dictionary.get('group')
         id = dictionary.get('id')
         is_connected = dictionary.get('isConnected')
@@ -176,10 +176,10 @@ class NetworkInterface(object):
         services = dictionary.get("services")
         speed = dictionary.get('speed')
         static_ip = dictionary.get('staticIp')
-        static_ip6 = dictionary.get('staticIp6')
+        static_ip_6 = dictionary.get('staticIp6')
         stats = cohesity_management_sdk.models.interface_stats.InterfaceStats.from_dictionary(dictionary.get('stats')) if dictionary.get('stats') else None
         subnet = dictionary.get('subnet')
-        subnet6 = dictionary.get('subnet6')
+        subnet_6 = dictionary.get('subnet6')
         mtype = dictionary.get('type')
         virtual_ip = dictionary.get('virtualIp')
 
@@ -191,7 +191,7 @@ class NetworkInterface(object):
             bond_slaves_details,
             bonding_mode,
             gateway,
-            gateway6,
+            gateway_6,
             group,
             id,
             is_connected,
@@ -204,10 +204,10 @@ class NetworkInterface(object):
             services,
             speed,
             static_ip,
-            static_ip6,
+            static_ip_6,
             stats,
             subnet,
-            subnet6,
+            subnet_6,
             mtype,
             virtual_ip
 )
\ No newline at end of file
