@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class NodeInterfacePair(object):
 
@@ -8,28 +7,30 @@ class NodeInterfacePair(object):
 
     Specifies a node ID and interface tuple.
 
+
     Attributes:
+
         iface_name (string): Specifies the name of the interface.
         node_id (long|int): Specifies list of node IDs.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "iface_name":'ifaceName',
-        "node_id":'nodeId'
+        "node_id":'nodeId',
     }
-
     def __init__(self,
                  iface_name=None,
-                 node_id=None):
+                 node_id=None,
+            ):
+
         """Constructor for the NodeInterfacePair class"""
 
         # Initialize members of the class
         self.iface_name = iface_name
         self.node_id = node_id
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -52,5 +53,7 @@ class NodeInterfacePair(object):
         node_id = dictionary.get('nodeId')
 
         # Return an object of this model
-        return cls(iface_name,
-                   node_id)
+        return cls(
+            iface_name,
+            node_id
+)
\ No newline at end of file
