@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class ObjectClassSearchPrincipalsEnum(object):
 
@@ -12,6 +12,7 @@ class ObjectClassSearchPrincipalsEnum(object):
         KGROUP: TODO: type description here.
         KCOMPUTER: TODO: type description here.
         KWELLKNOWNPRINCIPAL: TODO: type description here.
+        KSERVICEACCOUNT: TODO: type description here.
 
     """
 
@@ -23,3 +24,5 @@ class ObjectClassSearchPrincipalsEnum(object):
 
     KWELLKNOWNPRINCIPAL = 'kWellKnownPrincipal'
 
+    KSERVICEACCOUNT = 'kServiceAccount'
+
