@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class ProtectionJobSummaryStats(object):
 
@@ -8,24 +7,26 @@ class ProtectionJobSummaryStats(object):
 
     Specifies statistics about a Protection Job.
 
+
     Attributes:
+
         average_run_time_usecs (long|int): Specifies the average run time of
             all successful Protection Runs. It is specified as a Unix epoch
             Timestamp (in microseconds).
         fastest_run_time_usecs (long|int): Specifies the time taken for a
-            fastest successful Protection Run so far. It is specified as a
-            Unix epoch Timestamp (in microseconds).
+            fastest successful Protection Run so far. It is specified as a Unix
+            epoch Timestamp (in microseconds).
         num_canceled_runs (long|int): Specifies the number of runs that were
             cancelled.
-        num_failed_runs (long|int): Specifies the number of runs that failed
-            to finish.
+        num_failed_runs (long|int): Specifies the number of runs that failed to
+            finish.
         num_sla_violations (long|int): Specifies the number of runs having SLA
             violations.
         num_successful_runs (long|int): Specifies the number of runs that
             finished successfully.
         slowest_run_time_usecs (long|int): Specifies the time taken for a
-            slowest successful Protection Run so far. It is specified as a
-            Unix epoch Timestamp (in microseconds).
+            slowest successful Protection Run so far. It is specified as a Unix
+            epoch Timestamp (in microseconds).
         total_bytes_read_from_source (long|int): Specifies the total amount of
             data read from the source (so far).
         total_logical_backup_size_bytes (long|int): Specifies the size of the
@@ -33,15 +34,15 @@ class ProtectionJobSummaryStats(object):
             storage after the snapshot is taken. The logical size of the data
             on the source if the data is fully hydrated or expanded and not
             reduced by change-block tracking, compression and deduplication.
-        total_physical_backup_size_bytes (long|int): Specifies the total
-            amount of physical space used on the Cohesity Cluster to store the
+        total_physical_backup_size_bytes (long|int): Specifies the total amount
+            of physical space used on the Cohesity Cluster to store the
             protected object after being reduced by change-block tracking,
             compression and deduplication. For example, if the logical backup
-            size is 1GB, but only 1MB was used on the Cohesity Cluster to
-            store it, this field be equal to 1MB.
-
+            size is 1GB, but only 1MB was used on the Cohesity Cluster to store
+            it, this field be equal to 1MB.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "average_run_time_usecs":'averageRunTimeUsecs',
@@ -53,9 +54,8 @@ class ProtectionJobSummaryStats(object):
         "slowest_run_time_usecs":'slowestRunTimeUsecs',
         "total_bytes_read_from_source":'totalBytesReadFromSource',
         "total_logical_backup_size_bytes":'totalLogicalBackupSizeBytes',
-        "total_physical_backup_size_bytes":'totalPhysicalBackupSizeBytes'
+        "total_physical_backup_size_bytes":'totalPhysicalBackupSizeBytes',
     }
-
     def __init__(self,
                  average_run_time_usecs=None,
                  fastest_run_time_usecs=None,
@@ -66,7 +66,9 @@ class ProtectionJobSummaryStats(object):
                  slowest_run_time_usecs=None,
                  total_bytes_read_from_source=None,
                  total_logical_backup_size_bytes=None,
-                 total_physical_backup_size_bytes=None):
+                 total_physical_backup_size_bytes=None,
+            ):
+
         """Constructor for the ProtectionJobSummaryStats class"""
 
         # Initialize members of the class
@@ -81,7 +83,6 @@ class ProtectionJobSummaryStats(object):
         self.total_logical_backup_size_bytes = total_logical_backup_size_bytes
         self.total_physical_backup_size_bytes = total_physical_backup_size_bytes
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -112,15 +113,15 @@ class ProtectionJobSummaryStats(object):
         total_physical_backup_size_bytes = dictionary.get('totalPhysicalBackupSizeBytes')
 
         # Return an object of this model
-        return cls(average_run_time_usecs,
-                   fastest_run_time_usecs,
-                   num_canceled_runs,
-                   num_failed_runs,
-                   num_sla_violations,
-                   num_successful_runs,
-                   slowest_run_time_usecs,
-                   total_bytes_read_from_source,
-                   total_logical_backup_size_bytes,
-                   total_physical_backup_size_bytes)
-
-
+        return cls(
+            average_run_time_usecs,
+            fastest_run_time_usecs,
+            num_canceled_runs,
+            num_failed_runs,
+            num_sla_violations,
+            num_successful_runs,
+            slowest_run_time_usecs,
+            total_bytes_read_from_source,
+            total_logical_backup_size_bytes,
+            total_physical_backup_size_bytes
+)
\ No newline at end of file
