@@ -1,24 +1,19 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class RemovalReasonEnum(object):
 
     """Implementation of the 'RemovalReason' enum.
-
     Specifies the reason for the removal operation if there is a removal
-    operation going on.
-    'kUnknown' specifies that the removal reason is not known.
-    'kAutoHealthCheck' specifies that an internal health check found problems
-    with the Node.
-    'kUserGracefulRemoval' specifies that the user requested a graceful
-    removal.
-    'kUserAvoidAccess' specifies that the user requested to avoid access to
-    this Node.
-    'kUserGracefulNodeRemoval' specifies that the user requested a graceful
-    removal for all of the disks in this Node.
-    'kUserRemoveDownNode' specifies that the user requested a graceful
-    removal
-    of the Node while it is down.
+    operation going on. 'kUnknown' specifies that the removal reason is not
+    known. 'kAutoHealthCheck' specifies that an internal health check found
+    problems with the Node. 'kUserGracefulRemoval' specifies that the user
+    requested a graceful removal. 'kUserAvoidAccess' specifies that the user
+    requested to avoid access to this Node. 'kUserGracefulNodeRemoval'
+    specifies that the user requested a graceful removal for all of the disks
+    in this Node. 'kUserRemoveDownNode' specifies that the user requested a
+    graceful removal of the Node while it is down.
+
 
     Attributes:
         KUNKNOWN: TODO: type description here.
@@ -41,4 +36,3 @@ class RemovalReasonEnum(object):
     KUSERGRACEFULNODEREMOVAL = 'kUserGracefulNodeRemoval'
 
     KUSERREMOVEDOWNNODE = 'kUserRemoveDownNode'
-
