@@ -1,42 +1,49 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.entity_proto
-import cohesity_management_sdk.models.rename_object_param_proto
 import cohesity_management_sdk.models.pod_metadata
+import cohesity_management_sdk.models.rename_object_param_proto
+
 
 class RestoreKubernetesNamespacesParams(object):
 
     """Implementation of the 'RestoreKubernetesNamespacesParams' model.
 
-    TODO: type model description here.
+    TODO: type description here.
+
 
     Attributes:
-        backup_cluster_id (long|int): Cluster id of the cluster which
-            performed the backup.
+
+        backup_cluster_id (long|int): Cluster id of the cluster which performed
+            the backup.
         backup_job_name (string): Backup job that needs to be used for
             recovering the namespace.
-        cluster_entity (EntityProto): Specifies the attributes and the latest
-            statistics about an entity.
+        cluster_entity (EntityProto): This field is optional for a
+            kRecoverNamespaces task if the namespace is being restored to its
+            original parent source. If not specified, restored namespace will
+            be attached to its original cluster. This field is mandatory if the
+            namespace is being restored to a different parent source.
         cluster_software_version (string): Cluster software version.
-        init_container_image (string): Container image used to mounting PVCs
-            in temp pods.
-        is_protection_using_datamover_enabled (bool):  This indicates if
-            magneto_kubernetes_enable_protection_using_datamover is
-            true and the flag is enabled in the feature enabler.
+        init_container_image (string): Container image used to mounting PVCs in
+            temp pods.
+        is_protection_using_datamover_enabled (bool): This indicates if
+            magneto_kubernetes_enable_protection_using_datamover is true and
+            the flag is enabled in the feature enabler.
         management_namespace (string): Namespace in which restore job will be
             created in K8s cluster.
         pod_metadata_vec (list of PodMetadata): Information about pods in the
             namespace which was backed up.
-        rename_restored_object_param (RenameObjectParamProto): Message to
-            specify the prefix/suffix added to rename an object. At least one
-            of prefix or suffix must be specified. Please note that both
-            prefix and suffix can be specified.
-        s3_account_id (string): S3 account ID that was used to register the
+        rename_restored_object_param (RenameObjectParamProto): By default,
+            namespaces are restored with their original name. This field can be
+            used to specify the transformation ( i.e prefix/suffix) to be
+            applied to the source namespace to derive the new name of the
+            restored namespace.
+        s_3_account_id (string): S3 account ID that was used to register the
             source.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "backup_cluster_id":'backupClusterId',
@@ -48,9 +55,8 @@ class RestoreKubernetesNamespacesParams(object):
         "management_namespace":'managementNamespace',
         "pod_metadata_vec":'podMetadataVec',
         "rename_restored_object_param":'renameRestoredObjectParam',
-        "s3_account_id":'s3AccountId'
+        "s_3_account_id":'s3AccountId',
     }
-
     def __init__(self,
                  backup_cluster_id=None,
                  backup_job_name=None,
@@ -61,7 +67,9 @@ class RestoreKubernetesNamespacesParams(object):
                  management_namespace=None,
                  pod_metadata_vec=None,
                  rename_restored_object_param=None,
-                 s3_account_id=None):
+                 s_3_account_id=None,
+            ):
+
         """Constructor for the RestoreKubernetesNamespacesParams class"""
 
         # Initialize members of the class
@@ -74,8 +82,7 @@ class RestoreKubernetesNamespacesParams(object):
         self.management_namespace = management_namespace
         self.pod_metadata_vec = pod_metadata_vec
         self.rename_restored_object_param = rename_restored_object_param
-        self.s3_account_id = s3_account_id
-
+        self.s_3_account_id = s_3_account_id
 
     @classmethod
     def from_dictionary(cls,
@@ -108,18 +115,18 @@ class RestoreKubernetesNamespacesParams(object):
             for structure in dictionary.get('podMetadataVec'):
                 pod_metadata_vec.append(cohesity_management_sdk.models.pod_metadata.PodMetadata.from_dictionary(structure))
         rename_restored_object_param = cohesity_management_sdk.models.rename_object_param_proto.RenameObjectParamProto.from_dictionary(dictionary.get('renameRestoredObjectParam')) if dictionary.get('renameRestoredObjectParam') else None
-        s3_account_id = dictionary.get('s3AccountId')
+        s_3_account_id = dictionary.get('s3AccountId')
 
         # Return an object of this model
-        return cls(backup_cluster_id,
-                   backup_job_name,
-                   cluster_entity,
-                   cluster_software_version,
-                   init_container_image,
-                   is_protection_using_datamover_enabled,
-                   management_namespace,
-                   pod_metadata_vec,
-                   rename_restored_object_param,
-                   s3_account_id)
-
-
+        return cls(
+            backup_cluster_id,
+            backup_job_name,
+            cluster_entity,
+            cluster_software_version,
+            init_container_image,
+            is_protection_using_datamover_enabled,
+            management_namespace,
+            pod_metadata_vec,
+            rename_restored_object_param,
+            s_3_account_id
+)
\ No newline at end of file
