@@ -1,18 +1,21 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.entity_proto
 
-class RestoreVmwareVMParams(object):
+
+class RestoreVMwareVMParams(object):
 
     """Implementation of the 'RestoreVMwareVMParams' model.
 
-    TODO: type model description here.
+    TODO: type description here.
+
 
     Attributes:
-        attempt_differential_restore (bool): This field is only applicable
-            when overwrite_existing_vm is set to true. If this field is true,
-            as part of overwrite existing vm, differential restore will be
+
+        attempt_differential_restore (bool): This field is only applicable when
+            overwrite_existing_vm is set to true. If this field is true, as
+            part of overwrite existing vm, differential restore will be
             attempted.
         catalog_uuid (string): Specifies the name of the catalog for vapp
             template recovery. This is applicable for recovery to a VCD.
@@ -20,6 +23,9 @@ class RestoreVmwareVMParams(object):
             instant recovery.
         datastore_entity_vec (list of EntityProto): Datastore entities if the
             restore is to alternate location.
+        is_on_prem_deploy (bool): This will be true if this is on prem deploy
+            task. attempt_differential_restore should also be set to true in
+            case of doing on prem deploy.
         org_vdc_network_name (string): Specifies the name of the org VDC
             network to be used for the recovery. This is applicable for
             recovery to a VCD.
@@ -38,27 +44,30 @@ class RestoreVmwareVMParams(object):
             custom attributes for the clone op.
         preserve_tags_during_clone (bool): Whether to preserve tags for the
             clone op.
-        resource_pool_entity (EntityProto): Specifies the attributes and the
-            latest statistics about an entity.
+        resource_pool_entity (EntityProto): Resource pool entity if the restore
+            is to alternate location.
         storage_profile_name (string): This is only populated for VCD restore
             to alternate location. It contains the name of the destination
             storage profile.
         storage_profile_vcd_uuid (string): This is only populated for VCD
             restore to alternate location. It contains the vcd uuid of the
             destination storage profile.
-        target_datastore_folder (EntityProto): Specifies the attributes and
-            the latest statistics about an entity.
-        target_vm_folder (EntityProto): Specifies the attributes and the
-            latest statistics about an entity.
-
+        target_datastore_folder (EntityProto): Folder where the restore
+            datastore should be created. This is applicable only when the VMs
+            are being cloned.
+        target_vm_folder (EntityProto): Folder where the VMs should be created.
+            This is applicable only when the VMs are being restored to an
+            alternate location or if clone is being performed.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "attempt_differential_restore":'attemptDifferentialRestore',
         "catalog_uuid":'catalogUuid',
         "copy_recovery":'copyRecovery',
         "datastore_entity_vec":'datastoreEntityVec',
+        "is_on_prem_deploy":'isOnPremDeploy',
         "org_vdc_network_name":'orgVdcNetworkName',
         "org_vdc_network_vcd_uuid":'orgVdcNetworkVcdUuid',
         "overwrite_existing_vm":'overwriteExistingVm',
@@ -69,14 +78,14 @@ class RestoreVmwareVMParams(object):
         "storage_profile_name":'storageProfileName',
         "storage_profile_vcd_uuid":'storageProfileVcdUuid',
         "target_datastore_folder":'targetDatastoreFolder',
-        "target_vm_folder":'targetVmFolder'
+        "target_vm_folder":'targetVmFolder',
     }
-
     def __init__(self,
                  attempt_differential_restore=None,
                  catalog_uuid=None,
                  copy_recovery=None,
                  datastore_entity_vec=None,
+                 is_on_prem_deploy=None,
                  org_vdc_network_name=None,
                  org_vdc_network_vcd_uuid=None,
                  overwrite_existing_vm=None,
@@ -87,14 +96,17 @@ class RestoreVmwareVMParams(object):
                  storage_profile_name=None,
                  storage_profile_vcd_uuid=None,
                  target_datastore_folder=None,
-                 target_vm_folder=None):
-        """Constructor for the RestoreVmwareVMParams class"""
+                 target_vm_folder=None,
+            ):
+
+        """Constructor for the RestoreVMwareVMParams class"""
 
         # Initialize members of the class
         self.attempt_differential_restore = attempt_differential_restore
         self.catalog_uuid = catalog_uuid
         self.copy_recovery = copy_recovery
         self.datastore_entity_vec = datastore_entity_vec
+        self.is_on_prem_deploy = is_on_prem_deploy
         self.org_vdc_network_name = org_vdc_network_name
         self.org_vdc_network_vcd_uuid = org_vdc_network_vcd_uuid
         self.overwrite_existing_vm = overwrite_existing_vm
@@ -107,7 +119,6 @@ class RestoreVmwareVMParams(object):
         self.target_datastore_folder = target_datastore_folder
         self.target_vm_folder = target_vm_folder
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -134,6 +145,7 @@ class RestoreVmwareVMParams(object):
             datastore_entity_vec = list()
             for structure in dictionary.get('datastoreEntityVec'):
                 datastore_entity_vec.append(cohesity_management_sdk.models.entity_proto.EntityProto.from_dictionary(structure))
+        is_on_prem_deploy = dictionary.get('isOnPremDeploy')
         org_vdc_network_name = dictionary.get('orgVdcNetworkName')
         org_vdc_network_vcd_uuid = dictionary.get('orgVdcNetworkVcdUuid')
         overwrite_existing_vm = dictionary.get('overwriteExistingVm')
@@ -147,20 +159,21 @@ class RestoreVmwareVMParams(object):
         target_vm_folder = cohesity_management_sdk.models.entity_proto.EntityProto.from_dictionary(dictionary.get('targetVmFolder')) if dictionary.get('targetVmFolder') else None
 
         # Return an object of this model
-        return cls(attempt_differential_restore,
-                   catalog_uuid,
-                   copy_recovery,
-                   datastore_entity_vec,
-                   org_vdc_network_name,
-                   org_vdc_network_vcd_uuid,
-                   overwrite_existing_vm,
-                   power_off_and_rename_existing_vm,
-                   preserve_custom_attributes_during_clone,
-                   preserve_tags_during_clone,
-                   resource_pool_entity,
-                   storage_profile_name,
-                   storage_profile_vcd_uuid,
-                   target_datastore_folder,
-                   target_vm_folder)
-
-
+        return cls(
+            attempt_differential_restore,
+            catalog_uuid,
+            copy_recovery,
+            datastore_entity_vec,
+            is_on_prem_deploy,
+            org_vdc_network_name,
+            org_vdc_network_vcd_uuid,
+            overwrite_existing_vm,
+            power_off_and_rename_existing_vm,
+            preserve_custom_attributes_during_clone,
+            preserve_tags_during_clone,
+            resource_pool_entity,
+            storage_profile_name,
+            storage_profile_vcd_uuid,
+            target_datastore_folder,
+            target_vm_folder
+)
\ No newline at end of file
