@@ -1,17 +1,16 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class SearchJobStatusEnum(object):
 
     """Implementation of the 'SearchJobStatus' enum.
-
-    Specifies the status of the search.
-    'kJobRunning' indicates that the Job/task is currently running.
-    'kJobFinished' indicates that the Job/task completed and finished.
-    'kJobFailed' indicates that the Job/task failed and did not complete.
-    'kJobCanceled' indicates that the Job/task was canceled.
+    Specifies the status of the search Job. 'kJobRunning' indicates that the
+    Job/task is currently running. 'kJobFinished' indicates that the Job/task
+    completed and finished. 'kJobFailed' indicates that the Job/task failed and
+    did not complete. 'kJobCanceled' indicates that the Job/task was canceled.
     'kJobPaused' indicates the Job/task is paused.
 
+
     Attributes:
         KJOBRUNNING: TODO: type description here.
         KJOBFINISHED: TODO: type description here.
@@ -30,4 +29,3 @@ class SearchJobStatusEnum(object):
     KJOBCANCELED = 'kJobCanceled'
 
     KJOBPAUSED = 'kJobPaused'
-
