@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.smb_permission
 import cohesity_management_sdk.models.subnet
 
+
 class Share(object):
 
     """Implementation of the 'Share' model.
@@ -11,24 +12,25 @@ class Share(object):
     Specifies the share details when request is made for list of shares
     filtered by ShareName parameter.
 
+
     Attributes:
+
         all_smb_mount_paths (list of string): Array of SMB Paths.  Specifies
             the possible paths that can be used to mount this Share as a SMB
-            share. If Active Directory has multiple account names; each
-            machine account has its own path.
+            share. If Active Directory has multiple account names; each machine
+            account has its own path.
         enable_filer_audit_log (bool): Specifies whether to enable filer audit
             log on this view alias.
-        enable_smb_encryption (bool): Specifies the SMB encryption for the
-            View Alias. If set, it enables the SMB encryption for the View
-            Alias. Encryption is supported only by SMB 3.x dialects. Dialects
-            that do not support would still access data in unencrypted
-            format.
+        enable_smb_encryption (bool): Specifies the SMB encryption for the View
+            Alias. If set, it enables the SMB encryption for the View Alias.
+            Encryption is supported only by SMB 3.x dialects. Dialects that do
+            not support would still access data in unencrypted format.
         enable_smb_view_discovery (bool): If set, it enables discovery of view
             alias for SMB.
-        enforce_smb_encryption (bool): Specifies the SMB encryption for all
-            the sessions for the View Alias. If set, encryption is enforced
-            for all the sessions for the View Alias. When enabled all future
-            and existing unencrypted sessions are disallowed.
+        enforce_smb_encryption (bool): Specifies the SMB encryption for all the
+            sessions for the View Alias. If set, encryption is enforced for all
+            the sessions for the View Alias. When enabled all future and
+            existing unencrypted sessions are disallowed.
         nfs_mount_path (string): Specifies the path for mounting this Share as
             an NFS share.
         path (string): Specifies the path information for this share.
@@ -43,13 +45,13 @@ class Share(object):
             addresses that have permissions to access the View Alias.
             (Overrides the Subnets specified at the global Cohesity Cluster
             level and View level.)
-        super_user_sids (list of string): Specifies a list of user sids who:
-            ave Superuser access to this share.
+        super_user_sids (list of string): Specifies a list of user sids who
+            have Superuser access to this share.
         tenant_id (string): Specifies the unique id of the tenant.
         view_name (string): Specifies the view name this share belongs to.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "all_smb_mount_paths":'allSmbMountPaths',
@@ -66,9 +68,8 @@ class Share(object):
         "subnet_whitelist":'subnetWhitelist',
         "super_user_sids":'superUserSids',
         "tenant_id":'tenantId',
-        "view_name":'viewName'
+        "view_name":'viewName',
     }
-
     def __init__(self,
                  all_smb_mount_paths=None,
                  enable_filer_audit_log=None,
@@ -84,7 +85,9 @@ class Share(object):
                  subnet_whitelist=None,
                  super_user_sids=None,
                  tenant_id=None,
-                 view_name=None):
+                 view_name=None,
+            ):
+
         """Constructor for the Share class"""
 
         # Initialize members of the class
@@ -104,7 +107,6 @@ class Share(object):
         self.tenant_id = tenant_id
         self.view_name = view_name
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -123,7 +125,7 @@ class Share(object):
             return None
 
         # Extract variables from the dictionary
-        all_smb_mount_paths = dictionary.get('allSmbMountPaths')
+        all_smb_mount_paths = dictionary.get("allSmbMountPaths")
         enable_filer_audit_log = dictionary.get('enableFilerAuditLog')
         enable_smb_encryption = dictionary.get('enableSmbEncryption')
         enable_smb_view_discovery = dictionary.get('enableSmbViewDiscovery')
@@ -143,25 +145,25 @@ class Share(object):
             subnet_whitelist = list()
             for structure in dictionary.get('subnetWhitelist'):
                 subnet_whitelist.append(cohesity_management_sdk.models.subnet.Subnet.from_dictionary(structure))
-        super_user_sids = dictionary.get('superUserSids')
+        super_user_sids = dictionary.get("superUserSids")
         tenant_id = dictionary.get('tenantId')
         view_name = dictionary.get('viewName')
 
         # Return an object of this model
-        return cls(all_smb_mount_paths,
-                   enable_filer_audit_log,
-                   enable_smb_encryption,
-                   enable_smb_view_discovery,
-                   enforce_smb_encryption,
-                   nfs_mount_path,
-                   path,
-                   s_3_access_path,
-                   share_name,
-                   share_permissions,
-                   smb_mount_path,
-                   subnet_whitelist,
-                   super_user_sids,
-                   tenant_id,
-                   view_name)
-
-
+        return cls(
+            all_smb_mount_paths,
+            enable_filer_audit_log,
+            enable_smb_encryption,
+            enable_smb_view_discovery,
+            enforce_smb_encryption,
+            nfs_mount_path,
+            path,
+            s_3_access_path,
+            share_name,
+            share_permissions,
+            smb_mount_path,
+            subnet_whitelist,
+            super_user_sids,
+            tenant_id,
+            view_name
+)
\ No newline at end of file
