@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class SnapshotInfo(object):
 
@@ -9,7 +8,9 @@ class SnapshotInfo(object):
     Specifies details about the snapshot task created to backup or copy one
     source object like a VM.
 
+
     Attributes:
+
         environment (EnvironmentSnapshotInfoEnum): Specifies the environment
             type (such as kVMware or kSQL) that contains the source to backup.
             Supported environment types such as 'kView', 'kSQL', 'kVMware',
@@ -20,14 +21,14 @@ class SnapshotInfo(object):
             indicates the View Protection Source environment. 'kPuppeteer'
             indicates the Cohesity's Remote Adapter. 'kPhysical' indicates the
             physical Protection Source environment. 'kPure' indicates the Pure
-            Storage Protection Source environment. 'Nimble' indicates the
+            Storage Protection Source environment. 'kNimble' indicates the
             Nimble Storage Protection Source environment. 'kAzure' indicates
             the Microsoft's Azure Protection Source environment. 'kNetapp'
             indicates the Netapp Protection Source environment. 'kAgent'
             indicates the Agent Protection Source environment. 'kGenericNas'
             indicates the Generic Network Attached Storage Protection Source
-            environment. 'kAcropolis' indicates the Acropolis Protection
-            Source environment. 'kPhsicalFiles' indicates the Physical Files
+            environment. 'kAcropolis' indicates the Acropolis Protection Source
+            environment. 'kPhysicalFiles' indicates the Physical Files
             Protection Source environment. 'kIsilon' indicates the Dell EMC's
             Isilon Protection Source environment. 'kGPFS' indicates IBM's GPFS
             Protection Source environment. 'kKVM' indicates the KVM Protection
@@ -37,25 +38,32 @@ class SnapshotInfo(object):
             Source environment. 'kOracle' indicates the Oracle Protection
             Source environment. 'kGCP' indicates the Google Cloud Platform
             Protection Source environment. 'kFlashBlade' indicates the Flash
-            Blade Protection Source environment. 'kAWSNative' indicates the
-            AWS Native Protection Source environment.
-            'kO365' indicates the Office 365 Protection Source environment.
-            'kO365Outlook' indicates Office 365 outlook Protection Source
-            environment. 'kHyperFlex' indicates the Hyper Flex Protection
-            Source environment. 'kGCPNative' indicates the GCP Native
-            Protection Source environment. 'kAzureNative' indicates the Azure
-            Native Protection Source environment. 'kKubernetes' indicates a
-            Kubernetes Protection Source environment. 'kElastifile' indicates
-            Elastifile Protection Source environment. 'kAD' indicates Active
-            Directory Protection Source environment. 'kRDSSnapshotManager'
-            indicates AWS RDS Protection Source environment. 'kCassandra'
-            indicates Cassandra Protection Source environment. 'kMongoDB'
-            indicates MongoDB Protection Source environment. 'kCouchbase'
-            indicates Couchbase Protection Source environment. 'kHdfs'
-            indicates Hdfs Protection Source environment. 'kHive' indicates
-            Hive Protection Source environment. 'kHBase' indicates HBase
-            Protection Source environment.'kUDA' indicates Universal Data
-            Adapter Protection Source environment.
+            Blade Protection Source environment. 'kAWSNative' indicates the AWS
+            Native Protection Source environment. 'kO365' indicates the Office
+            365 Protection Source environment. 'kO365Outlook' indicates Office
+            365 outlook Protection Source environment. 'kHyperFlex' indicates
+            the Hyper Flex Protection Source environment. 'kGCPNative'
+            indicates the GCP Native Protection Source environment.
+            'kAzureNative' indicates the Azure Native Protection Source
+            environment. 'kKubernetes' indicates a Kubernetes Protection Source
+            environment. 'kElastifile' indicates Elastifile Protection Source
+            environment. 'kAD' indicates Active Directory Protection Source
+            environment. 'kRDSSnapshotManager' indicates AWS RDS Protection
+            Source environment. 'kCassandra' indicates Cassandra Protection
+            Source environment. 'kMongoDB' indicates MongoDB Protection Source
+            environment. 'kCouchbase' indicates Couchbase Protection Source
+            environment. 'kHdfs' indicates Hdfs Protection Source environment.
+            'kHive' indicates Hive Protection Source environment. 'kHBase'
+            indicates HBase Protection Source environment. 'kUDA' indicates
+            Universal Data Adapter Protection Source environment. 'kO365Teams'
+            indicates the Office365 Teams Protection Source environment.
+            'kO365Group' indicates the Office365 Groups Protection Source
+            environment. 'kO365Exchange' indicates the Office365 Mailbox
+            Protection Source environment. 'kO365OneDrive' indicates the
+            Office365 OneDrive Protection Source environment. 'kO365Sharepoint'
+            indicates the Office365 SharePoint Protection Source environment.
+            'kO365PublicFolders' indicates the Office365 PublicFolders
+            Protection Source environment.
         relative_snapshot_directory (string): Specifies the relative directory
             path from root path where the snapshot is stored.
         root_path (string): Specifies the root path where the snapshot is
@@ -67,9 +75,9 @@ class SnapshotInfo(object):
             created snapshot on the source
         view_name (string): Specifies the name of the View that is cloned.
             NOTE: This field is only populated for View cloning.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "environment":'environment',
@@ -77,16 +85,17 @@ class SnapshotInfo(object):
         "root_path":'rootPath',
         "source_snapshot_create_time_usecs":'sourceSnapshotCreateTimeUsecs',
         "source_snapshot_name":'sourceSnapshotName',
-        "view_name":'viewName'
+        "view_name":'viewName',
     }
-
     def __init__(self,
                  environment=None,
                  relative_snapshot_directory=None,
                  root_path=None,
                  source_snapshot_create_time_usecs=None,
                  source_snapshot_name=None,
-                 view_name=None):
+                 view_name=None,
+            ):
+
         """Constructor for the SnapshotInfo class"""
 
         # Initialize members of the class
@@ -97,7 +106,6 @@ class SnapshotInfo(object):
         self.source_snapshot_name = source_snapshot_name
         self.view_name = view_name
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -124,11 +132,11 @@ class SnapshotInfo(object):
         view_name = dictionary.get('viewName')
 
         # Return an object of this model
-        return cls(environment,
-                   relative_snapshot_directory,
-                   root_path,
-                   source_snapshot_create_time_usecs,
-                   source_snapshot_name,
-                   view_name)
-
-
+        return cls(
+            environment,
+            relative_snapshot_directory,
+            root_path,
+            source_snapshot_create_time_usecs,
+            source_snapshot_name,
+            view_name
+)
\ No newline at end of file
