@@ -1,16 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class TypeUdaProtectionSourceEnum(object):
 
     """Implementation of the 'TypeUdaProtectionSource' enum.
-
     Specifies the type of the managed Object in Universal Data Adapter
-    Protection Source.
-    Specifies the type of an Universal Data Adapter source entity.
-    'kCluster' indicates a Universal Data Adapter source, possibly distributed
-    over several physical nodes.
-    'kObject' indicates a generic object within the UDA environment.
+    Protection Source. Specifies the type of an Universal Data Adapter source
+    entity. 'kCluster' indicates a Universal Data Adapter source, possibly
+    distributed over several physical nodes. 'kObject' indicates a generic
+    object within the UDA environment.
+
 
     Attributes:
         KCLUSTER: TODO: type description here.
@@ -21,4 +20,3 @@ class TypeUdaProtectionSourceEnum(object):
     KCLUSTER = 'kCluster'
 
     KOBJECT = 'kObject'
-
