@@ -1,33 +1,34 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class UnRegisterApplicationServersParameters(object):
 
     """Implementation of the 'UnRegisterApplicationServersParameters' model.
 
-    Specifies the parameters required to unregister
-    Application Servers running in a Protection Source.
+    Specifies the parameters required to unregister Application Servers running
+    in a Protection Source.
+
 
     Attributes:
-        applications (list of ApplicationEnum): Specifies the types of
-            applications such as 'kSQL', 'kExchange' running on the Protection
-            Source. overrideDescription: true Supported environment types such
-            as 'kView', 'kSQL', 'kVMware', etc. NOTE: 'kPuppeteer' refers to
-            Cohesity's Remote Adapter. 'kVMware' indicates the VMware
+
+        applications (list of ApplicationsEnum): Specifies the types of
+            applications such as 'kSQL', 'kExchange', 'kAD' running on the
+            Protection Source. overrideDescription: true Supported environment
+            types such as 'kView', 'kSQL', 'kVMware', etc. NOTE: 'kPuppeteer'
+            refers to Cohesity's Remote Adapter. 'kVMware' indicates the VMware
             Protection Source environment. 'kHyperV' indicates the HyperV
             Protection Source environment. 'kSQL' indicates the SQL Protection
             Source environment. 'kView' indicates the View Protection Source
             environment. 'kPuppeteer' indicates the Cohesity's Remote Adapter.
             'kPhysical' indicates the physical Protection Source environment.
             'kPure' indicates the Pure Storage Protection Source environment.
-            'Nimble' indicates the Nimble Storage Protection Source
+            'kNimble' indicates the Nimble Storage Protection Source
             environment. 'kAzure' indicates the Microsoft's Azure Protection
             Source environment. 'kNetapp' indicates the Netapp Protection
             Source environment. 'kAgent' indicates the Agent Protection Source
             environment. 'kGenericNas' indicates the Generic Network Attached
             Storage Protection Source environment. 'kAcropolis' indicates the
-            Acropolis Protection Source environment. 'kPhsicalFiles' indicates
+            Acropolis Protection Source environment. 'kPhysicalFiles' indicates
             the Physical Files Protection Source environment. 'kIsilon'
             indicates the Dell EMC's Isilon Protection Source environment.
             'kGPFS' indicates IBM's GPFS Protection Source environment. 'kKVM'
@@ -39,40 +40,47 @@ class UnRegisterApplicationServersParameters(object):
             Cloud Platform Protection Source environment. 'kFlashBlade'
             indicates the Flash Blade Protection Source environment.
             'kAWSNative' indicates the AWS Native Protection Source
-            environment. 'kO365' indicates the Office 365
-            Protection Source environment. 'kO365Outlook' indicates Office 365
-            outlook Protection Source environment. 'kHyperFlex' indicates the
-            Hyper Flex Protection Source environment. 'kGCPNative' indicates
-            the GCP Native Protection Source environment. 'kAzureNative'
-            indicates the Azure Native Protection Source environment.
-            'kKubernetes' indicates a Kubernetes Protection Source
-            environment. 'kElastifile' indicates Elastifile Protection Source
-            environment. 'kAD' indicates Active Directory Protection Source
-            environment. 'kRDSSnapshotManager' indicates AWS RDS Protection
-            Source environment. 'kCassandra' indicates Cassandra Protection
-            Source environment. 'kMongoDB' indicates MongoDB Protection Source
-            environment. 'kCouchbase' indicates Couchbase Protection Source
-            environment. 'kHdfs' indicates Hdfs Protection Source environment.
-            'kHive' indicates Hive Protection Source environment. 'kHBase'
-            indicates HBase Protection Source environment.
-            'kUDA' indicates Universal Data Adapter Protection Source
-            environment.
-
+            environment. 'kO365' indicates the Office 365 Protection Source
+            environment. 'kO365Outlook' indicates Office 365 outlook Protection
+            Source environment. 'kHyperFlex' indicates the Hyper Flex
+            Protection Source environment. 'kGCPNative' indicates the GCP
+            Native Protection Source environment. 'kAzureNative' indicates the
+            Azure Native Protection Source environment. 'kKubernetes' indicates
+            a Kubernetes Protection Source environment. 'kElastifile' indicates
+            Elastifile Protection Source environment. 'kAD' indicates Active
+            Directory Protection Source environment. 'kRDSSnapshotManager'
+            indicates AWS RDS Protection Source environment. 'kCassandra'
+            indicates Cassandra Protection Source environment. 'kMongoDB'
+            indicates MongoDB Protection Source environment. 'kCouchbase'
+            indicates Couchbase Protection Source environment. 'kHdfs'
+            indicates Hdfs Protection Source environment. 'kHive' indicates
+            Hive Protection Source environment. 'kHBase' indicates HBase
+            Protection Source environment. 'kUDA' indicates Universal Data
+            Adapter Protection Source environment. 'kO365Teams' indicates the
+            Office365 Teams Protection Source environment. 'kO365Group'
+            indicates the Office365 Groups Protection Source environment.
+            'kO365Exchange' indicates the Office365 Mailbox Protection Source
+            environment. 'kO365OneDrive' indicates the Office365 OneDrive
+            Protection Source environment. 'kO365Sharepoint' indicates the
+            Office365 SharePoint Protection Source environment.
+            'kO365PublicFolders' indicates the Office365 PublicFolders
+            Protection Source environment.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "applications":'applications'
+        "applications":'applications',
     }
-
     def __init__(self,
-                 applications=None):
+                 applications=None,
+            ):
+
         """Constructor for the UnRegisterApplicationServersParameters class"""
 
         # Initialize members of the class
         self.applications = applications
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -91,9 +99,9 @@ class UnRegisterApplicationServersParameters(object):
             return None
 
         # Extract variables from the dictionary
-        applications = dictionary.get('applications')
+        applications = dictionary.get("applications")
 
         # Return an object of this model
-        return cls(applications)
-
-
+        return cls(
+            applications
+)
\ No newline at end of file
