@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class UpdateApplicationServerParameters(object):
 
@@ -9,25 +8,27 @@ class UpdateApplicationServerParameters(object):
     Specifies the parameters required to modify the parameters of previously
     registered Application Servers in a Protection Source.
 
+
     Attributes:
-        applications (list of ApplicationEnum): Specifies the types of
-            applications such as 'kSQL', 'kExchange' running on the Protection
-            Source. overrideDescription: true Supported environment types such
-            as 'kView', 'kSQL', 'kVMware', etc. NOTE: 'kPuppeteer' refers to
-            Cohesity's Remote Adapter. 'kVMware' indicates the VMware
+
+        applications (list of ApplicationsEnum): Specifies the types of
+            applications such as 'kSQL', 'kExchange', 'kAD' running on the
+            Protection Source. overrideDescription: true Supported environment
+            types such as 'kView', 'kSQL', 'kVMware', etc. NOTE: 'kPuppeteer'
+            refers to Cohesity's Remote Adapter. 'kVMware' indicates the VMware
             Protection Source environment. 'kHyperV' indicates the HyperV
             Protection Source environment. 'kSQL' indicates the SQL Protection
             Source environment. 'kView' indicates the View Protection Source
             environment. 'kPuppeteer' indicates the Cohesity's Remote Adapter.
             'kPhysical' indicates the physical Protection Source environment.
             'kPure' indicates the Pure Storage Protection Source environment.
-            'Nimble' indicates the Nimble Storage Protection Source
+            'kNimble' indicates the Nimble Storage Protection Source
             environment. 'kAzure' indicates the Microsoft's Azure Protection
             Source environment. 'kNetapp' indicates the Netapp Protection
             Source environment. 'kAgent' indicates the Agent Protection Source
             environment. 'kGenericNas' indicates the Generic Network Attached
             Storage Protection Source environment. 'kAcropolis' indicates the
-            Acropolis Protection Source environment. 'kPhsicalFiles' indicates
+            Acropolis Protection Source environment. 'kPhysicalFiles' indicates
             the Physical Files Protection Source environment. 'kIsilon'
             indicates the Dell EMC's Isilon Protection Source environment.
             'kGPFS' indicates IBM's GPFS Protection Source environment. 'kKVM'
@@ -39,31 +40,40 @@ class UpdateApplicationServerParameters(object):
             Cloud Platform Protection Source environment. 'kFlashBlade'
             indicates the Flash Blade Protection Source environment.
             'kAWSNative' indicates the AWS Native Protection Source
-            environment. 'kO365' indicates the Office 365
-            Protection Source environment. 'kO365Outlook' indicates Office 365
-            outlook Protection Source environment. 'kHyperFlex' indicates the
-            Hyper Flex Protection Source environment. 'kGCPNative' indicates
-            the GCP Native Protection Source environment. 'kAzureNative'
-            indicates the Azure Native Protection Source environment.
-            'kKubernetes' indicates a Kubernetes Protection Source
-            environment. 'kElastifile' indicates Elastifile Protection Source
-            environment. 'kAD' indicates Active Directory Protection Source
-            environment. 'kRDSSnapshotManager' indicates AWS RDS Protection
-            Source environment. 'kCassandra' indicates Cassandra Protection
-            Source environment. 'kMongoDB' indicates MongoDB Protection Source
-            environment. 'kCouchbase' indicates Couchbase Protection Source
-            environment. 'kHdfs' indicates Hdfs Protection Source environment.
-            'kHive' indicates Hive Protection Source environment. 'kHBase'
-            indicates HBase Protection Source environment.
+            environment. 'kO365' indicates the Office 365 Protection Source
+            environment. 'kO365Outlook' indicates Office 365 outlook Protection
+            Source environment. 'kHyperFlex' indicates the Hyper Flex
+            Protection Source environment. 'kGCPNative' indicates the GCP
+            Native Protection Source environment. 'kAzureNative' indicates the
+            Azure Native Protection Source environment. 'kKubernetes' indicates
+            a Kubernetes Protection Source environment. 'kElastifile' indicates
+            Elastifile Protection Source environment. 'kAD' indicates Active
+            Directory Protection Source environment. 'kRDSSnapshotManager'
+            indicates AWS RDS Protection Source environment. 'kCassandra'
+            indicates Cassandra Protection Source environment. 'kMongoDB'
+            indicates MongoDB Protection Source environment. 'kCouchbase'
+            indicates Couchbase Protection Source environment. 'kHdfs'
+            indicates Hdfs Protection Source environment. 'kHive' indicates
+            Hive Protection Source environment. 'kHBase' indicates HBase
+            Protection Source environment. 'kUDA' indicates Universal Data
+            Adapter Protection Source environment. 'kO365Teams' indicates the
+            Office365 Teams Protection Source environment. 'kO365Group'
+            indicates the Office365 Groups Protection Source environment.
+            'kO365Exchange' indicates the Office365 Mailbox Protection Source
+            environment. 'kO365OneDrive' indicates the Office365 OneDrive
+            Protection Source environment. 'kO365Sharepoint' indicates the
+            Office365 SharePoint Protection Source environment.
+            'kO365PublicFolders' indicates the Office365 PublicFolders
+            Protection Source environment.
         encryption_key (string): If set, user has encrypted the credential with
             'user_ecryption_key'. It is assumed that credentials are first
             encrypted using internal magento key and then encrypted using user
             encryption key.
         has_persistent_agent (bool): Set this to true if a persistent agent is
             running on the host. If this is specified, then credentials would
-            not be used to log into the host environment. This mechanism may
-            be used in environments such as VMware to get around UAC
-            permission issues by running the agent as a service with the right
+            not be used to log into the host environment. This mechanism may be
+            used in environments such as VMware to get around UAC permission
+            issues by running the agent as a service with the right
             credentials. If this field is not specified, credentials must be
             specified.
         is_internal_encrypted (bool): Set to true if credentials are encrypted
@@ -71,12 +81,11 @@ class UpdateApplicationServerParameters(object):
         password (string): Specifies password of the username to access the
             target source.
         protection_source_id (long|int): Specifies the Id of the Protection
-            Source that contains one or more Application Servers running on
-            it.
+            Source that contains one or more Application Servers running on it.
         username (string): Specifies username to access the target source.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "applications":'applications',
@@ -85,9 +94,8 @@ class UpdateApplicationServerParameters(object):
         "is_internal_encrypted":'isInternalEncrypted',
         "password":'password',
         "protection_source_id":'protectionSourceId',
-        "username":'username'
+        "username":'username',
     }
-
     def __init__(self,
                  applications=None,
                  encryption_key=None,
@@ -95,7 +103,9 @@ class UpdateApplicationServerParameters(object):
                  is_internal_encrypted=None,
                  password=None,
                  protection_source_id=None,
-                 username=None):
+                 username=None,
+            ):
+
         """Constructor for the UpdateApplicationServerParameters class"""
 
         # Initialize members of the class
@@ -107,7 +117,6 @@ class UpdateApplicationServerParameters(object):
         self.protection_source_id = protection_source_id
         self.username = username
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -126,7 +135,7 @@ class UpdateApplicationServerParameters(object):
             return None
 
         # Extract variables from the dictionary
-        applications = dictionary.get('applications')
+        applications = dictionary.get("applications")
         encryption_key = dictionary.get('encryptionKey')
         has_persistent_agent = dictionary.get('hasPersistentAgent')
         is_internal_encrypted = dictionary.get('isInternalEncrypted')
@@ -135,12 +144,12 @@ class UpdateApplicationServerParameters(object):
         username = dictionary.get('username')
 
         # Return an object of this model
-        return cls(applications,
-                   encryption_key,
-                   has_persistent_agent,
-                   is_internal_encrypted,
-                   password,
-                   protection_source_id,
-                   username)
-
-
+        return cls(
+            applications,
+            encryption_key,
+            has_persistent_agent,
+            is_internal_encrypted,
+            password,
+            protection_source_id,
+            username
+)
\ No newline at end of file
