@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class UpdateBondResult(object):
 
@@ -8,25 +7,27 @@ class UpdateBondResult(object):
 
     Specifies the result of a request to update a new bond.
 
+
     Attributes:
+
         message (string): Specifies a message describing the result of the
             operation.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "message":'message'
+        "message":'message',
     }
-
     def __init__(self,
-                 message=None):
+                 message=None,
+            ):
+
         """Constructor for the UpdateBondResult class"""
 
         # Initialize members of the class
         self.message = message
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -48,6 +49,6 @@ class UpdateBondResult(object):
         message = dictionary.get('message')
 
         # Return an object of this model
-        return cls(message)
-
-
+        return cls(
+            message
+)
\ No newline at end of file
