@@ -144,12 +144,12 @@ class View(object):
             of a view does not match any of the above. In this case, the
             constant is used as 'catch-all'.
         qos (QoS): Specifies the Quality of Service (QoS) Policy for the View.
-        s3_access_path (string): Specifies the path to access this View as an
+        s_3_access_path (string): Specifies the path to access this View as an
             S3 share.
-        s3_folder_support_enabled (bool): Specifies whether to support s3
+        s_3_folder_support_enabled (bool): Specifies whether to support s3
             folder support feature on the view. This parameter can only be set
             during create and cannot be changed.
-        s3_key_mapping_config (S3KeyMappingConfigEnum): Specifies the S3 key
+        s_3_key_mapping_config (S3KeyMappingConfigEnum): Specifies the S3 key
             mapping config of the view. This parameter can only be set during
             create and cannot be changed. Configuration of S3 key mapping. 
             Specifies the type of S3 key mapping config.
@@ -235,9 +235,9 @@ class View(object):
         "owner_sid":'ownerSid',
         "protocol_access":'protocolAccess',
         "qos":'qos',
-        "s3_access_path":'s3AccessPath',
-        "s3_folder_support_enabled":'s3FolderSupportEnabled',
-        "s3_key_mapping_config":'s3KeyMappingConfig',
+        "s_3_access_path":'s3AccessPath',
+        "s_3_folder_support_enabled":'s3FolderSupportEnabled',
+        "s_3_key_mapping_config":'s3KeyMappingConfig',
         "security_mode":'securityMode',
         "share_permissions":'sharePermissions',
         "smb_mount_path":'smbMountPath',
@@ -298,9 +298,9 @@ class View(object):
                  owner_sid=None,
                  protocol_access=None,
                  qos=None,
-                 s3_access_path=None,
-                 s3_folder_support_enabled=None,
-                 s3_key_mapping_config=None,
+                 s_3_access_path=None,
+                 s_3_folder_support_enabled=None,
+                 s_3_key_mapping_config=None,
                  security_mode=None,
                  share_permissions=None,
                  smb_mount_path=None,
@@ -364,9 +364,9 @@ class View(object):
         self.owner_sid = owner_sid
         self.protocol_access = protocol_access
         self.qos = qos
-        self.s3_access_path = s3_access_path
-        self.s3_folder_support_enabled = s3_folder_support_enabled
-        self.s3_key_mapping_config = s3_key_mapping_config
+        self.s_3_access_path = s_3_access_path
+        self.s_3_folder_support_enabled = s_3_folder_support_enabled
+        self.s_3_key_mapping_config = s_3_key_mapping_config
         self.security_mode = security_mode
         self.share_permissions = share_permissions
         self.smb_mount_path = smb_mount_path
@@ -452,9 +452,9 @@ class View(object):
         owner_sid = dictionary.get('ownerSid')
         protocol_access = dictionary.get('protocolAccess')
         qos = cohesity_management_sdk.models.qo_s.QoS.from_dictionary(dictionary.get('qos')) if dictionary.get('qos') else None
-        s3_access_path = dictionary.get('s3AccessPath')
-        s3_folder_support_enabled = dictionary.get('s3FolderSupportEnabled')
-        s3_key_mapping_config = dictionary.get('s3KeyMappingConfig')
+        s_3_access_path = dictionary.get('s3AccessPath')
+        s_3_folder_support_enabled = dictionary.get('s3FolderSupportEnabled')
+        s_3_key_mapping_config = dictionary.get('s3KeyMappingConfig')
         security_mode = dictionary.get('securityMode')
         share_permissions = None
         if dictionary.get('sharePermissions') != None:
@@ -524,9 +524,9 @@ class View(object):
             owner_sid,
             protocol_access,
             qos,
-            s3_access_path,
-            s3_folder_support_enabled,
-            s3_key_mapping_config,
+            s_3_access_path,
+            s_3_folder_support_enabled,
+            s_3_key_mapping_config,
             security_mode,
             share_permissions,
             smb_mount_path,
