@@ -1,37 +1,40 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.user_quota
 
+
 class ViewUserQuotaParameters(object):
 
     """Implementation of the 'ViewUserQuotaParameters' model.
 
     Specifies the params to create and edit a user quota policy in a view.
 
+
     Attributes:
+
         user_quota_policy (UserQuota): The user quota policies that need to be
             updated.
         view_name (string): View name of input view.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "user_quota_policy":'userQuotaPolicy',
-        "view_name":'viewName'
+        "view_name":'viewName',
     }
-
     def __init__(self,
                  user_quota_policy=None,
-                 view_name=None):
+                 view_name=None,
+            ):
+
         """Constructor for the ViewUserQuotaParameters class"""
 
         # Initialize members of the class
         self.user_quota_policy = user_quota_policy
         self.view_name = view_name
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -54,7 +57,7 @@ class ViewUserQuotaParameters(object):
         view_name = dictionary.get('viewName')
 
         # Return an object of this model
-        return cls(user_quota_policy,
-                   view_name)
-
-
+        return cls(
+            user_quota_policy,
+            view_name
+)
\ No newline at end of file
